Usage
metaheurhyper(gridclassobject = examplegrid, searchtype = "grid", nrohyperparams = 3, iterations = 10, cores = 1, nholdout = 2, trials = 3, model = "rpart")
Arguments
gridclassobject
(GridClass) created by setgrid function in preprocomb package, defaults to examplegrid
searchtype
(character) grid or random search
nrohyperparams
(integer) number of hyperparameters used in random search, between 1 and 5, default to 3
iterations
(integer) number of iterations done for a restart
cores
(integer) number of cores used in computation of classification accuracies holdout rounds
nholdout
(integer) number of holdout rounds in computing classification accuracies
trials
(integer) number of trials
model
(character) caret name of predictive model, defaults to "rpart"